from __future__ import print_function
from pySecDec.integral_interface import IntegralLibrary
import sympy as sp

# load c++ library
fA66 = IntegralLibrary('fA66_phys/fA66_phys_pylink.so')

# choose integrator
fA66.use_Vegas(flags=2,epsrel=1e-4,maxeval=10**7)

 
# integrate non-Euclidean point;
s, t, pp4, msq = [90.,-2.5,1.6,1.] 
str_integral_without_prefactor, str_prefactor, str_integral_with_prefactor = fA66([s, t, pp4, msq])

# convert complex numbers from c++ to sympy notation
str_integral_with_prefactor = str_integral_with_prefactor.replace(',','+I*')
str_prefactor = str_prefactor.replace(',','+I*')
str_integral_without_prefactor = str_integral_without_prefactor.replace(',','+I*')

# convert result to sympy expressions
integral_with_prefactor = sp.sympify(str_integral_with_prefactor.replace('+/-','*value+error*'))
integral_with_prefactor_err = sp.sympify(str_integral_with_prefactor.replace('+/-','*value+error*'))
prefactor = sp.sympify(str_prefactor)
integral_without_prefactor = sp.sympify(str_integral_without_prefactor.replace('+/-','*value+error*'))
integral_without_prefactor_err = sp.sympify(str_integral_without_prefactor.replace('+/-','*value+error*'))

# numerical result
print('Numerical Result for non-Euclidean point:')
print('does NOT contain prefactor (s/msq)^(3/2)')
print('eps^0:', integral_with_prefactor.coeff('eps',0).coeff('value'), '+/- (', integral_with_prefactor_err.coeff('eps',0).coeff('error'), ')')

print('Result from SecDec-3 for non-Euclidean point:')
print('eps^0: -0.0442887356+I*0.01606818343 +- (2.45625148e-05+I*2.662108194e-05)')

